@@ -10,6 +10,8 @@ from enum import IntEnum, auto
 from pathlib import Path
 from typing import List, Optional, Union
 
+from fastdtlmapper import __version__
+
 
 @dataclass
 class Args:
@@ -58,7 +60,7 @@ class Args:
             + f"Duplication event cost = {self.dup_cost}\n"
             + f"Loss event cost = {self.los_cost}\n"
             + f"Transfer event cost = {self.trn_cost}\n"
-            + f"MCL inflation parameter = {self.inflation}\n"
+            + f"OrthoFinder MCL inflation parameter = {self.inflation}\n"
             + f"Number of random seed = {self.rseed}\n\n"
             + f"Start time = {unixtime_to_datestr(self._start_time)}\n"
             + f"End time = {unixtime_to_datestr(end_time)}\n"
@@ -86,7 +88,8 @@ def get_args(argv: Optional[List[str]] = None) -> Args:
         Args: Args Class
     """
     parser = argparse.ArgumentParser(
-        description="Fast genome-wide DTL event mapping tool"
+        description=f"Fast genome-wide DTL event mapping tool (v{__version__})",
+        add_help=False,
     )
 
     parser.add_argument(
@@ -95,7 +98,7 @@ def get_args(argv: Optional[List[str]] = None) -> Args:
         required=True,
         type=Path,
         help="Input Fasta(*.fa|*.faa|*.fasta), "
-        + "Genbank(*.gb|*.gbk|*.genbank) directory",
+        + "Genbank(*.gb|*.gbk|*.gbff) directory",
         metavar="IN",
     )
     parser.add_argument(
@@ -148,7 +151,7 @@ def get_args(argv: Optional[List[str]] = None) -> Args:
         default=default_trn_cost,
         metavar="",
     )
-    default_inflation = 1.5
+    default_inflation = 3.0
     parser.add_argument(
         "--inflation",
         type=float,
@@ -169,6 +172,19 @@ def get_args(argv: Optional[List[str]] = None) -> Args:
         default=default_rseed,
         metavar="",
     )
+    parser.add_argument(
+        "-v",
+        "--version",
+        version=f"v{__version__}",
+        help="Print version information",
+        action="version",
+    )
+    parser.add_argument(
+        "-h",
+        "--help",
+        help="Show this help message and exit",
+        action="help",
+    )
     #######################################################
     # Hidden test option for developer
     #######################################################
